@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.038000";
+$VERSION = "5.038002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.38.0) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.38.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.38.0
-    or die sprintf "%s: Perl lib version (5.38.0) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.38.2
+    or die sprintf "%s: Perl lib version (5.38.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,9 +84,9 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib/perl5/5.38/hppa1.1-linux',
-    archname => 'hppa1.1-linux',
-    cc => 'hppa1.1-unknown-linux-gnu-gcc',
+    archlibexp => '/usr/lib/perl5/5.38/hppa2.0-linux',
+    archname => 'hppa2.0-linux',
+    cc => 'hppa2.0-unknown-linux-gnu-gcc',
     d_readlink => 'define',
     d_symlink => 'define',
     dlext => 'so',
@@ -96,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/lib /lib',
+    libpth => '/usr/lib',
     osname => 'linux',
     osvers => '5.10.61-gentoo',
     path_sep => ':',
     privlibexp => '/usr/lib/perl5/5.38',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/local/lib/perl5/5.38/hppa1.1-linux',
+    sitearchexp => '/usr/local/lib/perl5/5.38/hppa2.0-linux',
     sitelibexp => '/usr/local/lib/perl5/5.38',
     so => 'so',
     useithreads => undef,
     usevendorprefix => 'define',
-    version => '5.38.0',
+    version => '5.38.2',
 };
